@@ -9,13 +9,13 @@ import warnings
 from django.conf import settings
 from django.contrib.auth import authenticate
 from django.core.exceptions import ImproperlyConfigured
-from django.middleware.csrf import _sanitize_token, constant_time_compare
-from django.utils.translation import ugettext as _
+from django.middleware.csrf import _sanitize_token
+from django.utils.translation import gettext as _
 
 from six.moves.urllib.parse import urlparse
 
 from tastypie.compat import (
-    get_user_model, get_username_field, unsalt_token, is_authenticated
+    get_user_model, get_username_field, compare_sanitized_tokens, InvalidTokenFormat
 )
 from tastypie.http import HttpUnauthorized
 
@@ -306,10 +306,10 @@ class SessionAuthentication(Authentication):
         # the serialized bodies.
 
         if request.method in ('GET', 'HEAD', 'OPTIONS', 'TRACE'):
-            return is_authenticated(request.user)
+            return request.user.is_authenticated
 
         if getattr(request, '_dont_enforce_csrf_checks', False):
-            return is_authenticated(request.user)
+            return request.user.is_authenticated
 
         csrf_token = _sanitize_token(request.COOKIES.get(settings.CSRF_COOKIE_NAME, ''))
 
@@ -325,13 +325,15 @@ class SessionAuthentication(Authentication):
                 return False
 
         request_csrf_token = request.META.get('HTTP_X_CSRFTOKEN', '')
-        request_csrf_token = _sanitize_token(request_csrf_token)
-
-        if not constant_time_compare(unsalt_token(request_csrf_token),
-                                     unsalt_token(csrf_token)):
+        try:
+            request_csrf_token = _sanitize_token(request_csrf_token)
+        except InvalidTokenFormat:
             return False
 
-        return is_authenticated(request.user)
+        if not compare_sanitized_tokens(request_csrf_token, csrf_token):
+            return False
+
+        return request.user.is_authenticated
 
     def get_identifier(self, request):
         """
